@@ -1,6 +1,7 @@
 import json
 import uuid
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, Union
+from json.decoder import JSONDecodeError
 
 import boto3
 
@@ -10,7 +11,7 @@ class SfnCall:
         self.__sfn_client = boto3.client('stepfunctions')
         self.__state_machine_arn = state_machine_arn
 
-    def call(self, data: Dict[Any, Any]) -> Dict[Any, Any]:
+    def call(self, data: Dict[Any, Any]) -> Union[str, Dict[str, Any]]:
         response = self.__sfn_client.start_sync_execution(
             stateMachineArn=self.__state_machine_arn,
             name=str(uuid.uuid4()),
@@ -33,7 +34,7 @@ class SfnCall:
         return output
 
     @staticmethod
-    def __http_like_handling(output: Dict[Any, Any]) -> Dict[Any, Any]:
+    def __http_like_handling(output: Dict[Any, Any]) -> Union[str, Dict[str, Any]]:
         """
         A function that treats responses/outputs from step functions state machine as an http response:
         for example, it looks for keys like "http_status" or "body".
@@ -41,10 +42,18 @@ class SfnCall:
         :param output: The output data from step functions state machine.
 
         :return: Original output, if the output does not contain http-like features
-            Body of the output otherwise.
+            Body of the output otherwise (JSON deserialized, if possible).
         """
-        http_status: Optional[int] = output.get('http_status')
-        http_body: Dict[Any, Any] = output.get('body') or {}
+        http_status: Optional[int] = output.get('http_status') or output.get('statusCode')
+        http_body: Union[str, Dict[str, Any]] = None   
+        
+        if isinstance(body := output.get('body'), str):
+            try:
+                http_body = json.loads(body)
+            except JSONDecodeError:
+                http_body = body
+        else:
+            http_body = body
 
         if isinstance(http_status, int):
             if http_status >= 400:
